@@ -3,20 +3,25 @@ library(webTRISr)
 
 test_that("webtris_sites() returns dataframe", {
     x <- webtris_sites()
-    
+
     expect_is(x, class = "data.frame")
-    expected_cols <- c("Id", "Name", "Description", "Longitude", 
+    expected_cols <- c("Id", "Name", "Description", "Longitude",
         "Latitude", "Status")
     expect_equivalent(expected_cols, colnames(x))
+
+    x <- webtris_sites('3', sf = TRUE)
+    expect_is(x, class = "sf")
+    expected_cols <- c("Id", "Name", "Description", "Status", "geometry")
+    expect_equivalent(expected_cols, colnames(x))
 })
 
 
 test_that("webtris_quality(daily=FALSE) returns dataframe", {
     x <- webtris_sites(1)
-    
-    
+
+
     expect_is(x, class = "data.frame")
-    expected_cols <- c("Id", "Name", "Description", "Longitude", 
+    expected_cols <- c("Id", "Name", "Description", "Longitude",
         "Latitude", "Status")
     expect_equivalent(expected_cols, colnames(x))
 })
